OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Onjuist wachtwoord",
    "The new password can not be the same as the previous one" : "Het nieuwe password mag niet gelijk zijn aan het oude",
    "No user supplied" : "Geen gebruiker opgegeven",
    "Authentication error" : "Authenticatie fout",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Voer een beheerdersherstelwachtwoord in, anders zullen alle gebruikersgegevens verloren gaan",
    "Wrong admin recovery password. Please check the password and try again." : "Onjuist beheerdersherstelwachtwoord. Controleer het wachtwoord en probeer het opnieuw.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "De Back-end ondersteunt geen wachtwoordwijzigingen, maar de cryptosleutel van de gebruiker is succesvol bijgewerkt.",
    "Unable to change password" : "Kan wachtwoord niet wijzigen",
    "%s password changed successfully" : "%s wachtwoord succesvol gewijzigd.",
    "Couldn't send reset email. Please contact your administrator." : "Kon herstel e-mail niet versturen. Neem contact op met uw beheerder.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "installeren en bijwerken applicaties via de app store of Federated Cloud Sharing",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cUrl gebruikt een verouderde %s versie (%s). Werk het besturingssysteem bij of functies als %s zullen niet betrouwbaar werken.",
    "A problem occurred, please check your log files (Error: %s)" : "Er trad een een probleem op, controleer uw logbestanden (Fout: %s).",
    "Migration Completed" : "Migratie gereed",
    "Group already exists." : "Groep bestaat al.",
    "Unable to add group." : "Kan groep niet toevoegen.",
    "Unable to delete group." : "Kan groep niet verwijderen.",
    "log-level out of allowed range" : "loggingniveau buiten toegestane bereik",
    "Saved" : "Bewaard",
    "test email settings" : "test e-mailinstellingen",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Er ontstond een probleem bij het versturen van de e-mail. Controleer uw instellingen.  (Fout: %s)",
    "Email sent" : "E-mail verzonden",
    "You need to set your user email before being able to send test emails." : "U moet uw e-mailadres invoeren voordat u testberichten kunt versturen.",
    "Couldn't change the email address because the user does not exist" : "Kon het e-mailadres niet wijzigen omdat de gebruiker niet bestaat",
    "Couldn't change the email address because the token is invalid" : "Kon het e-mailadres niet wijzigen omdat het token ongeldig is",
    "Invalid mail address" : "Ongeldig e-mailadres",
    "A user with that name already exists." : "Er bestaat al een gebruiker met die naam.",
    "Unable to create user." : "Kan gebruiker niet aanmaken.",
    "Your %s account was created" : "Uw %s account is aangemaakt",
    "Unable to delete user." : "Kan gebruiker niet verwijderen.",
    "Forbidden" : "Verboden",
    "Invalid user" : "Ongeldige gebruiker",
    "Unable to change mail address" : "Kan e-mailadres niet wijzigen",
    "Email has been changed successfully." : "E-mailadres succesvol gewijzigd.",
    "An email has been sent to this address for confirmation" : "Het e-mailbericht is ter bevestiging naar dit adres gestuurd",
    "No email was sent because you already sent one recently. Please try again later." : "Er is geen e-mailbericht verstuurd, omdat u onlangs al een mailtje verstuurde. Probeer het later opnieuw,",
    "Your full name has been changed." : "Uw volledige naam is gewijzigd.",
    "Unable to change full name" : "Kan de volledige naam niet wijzigen",
    "%s email address confirm" : "%s e-mailadres bevestigen",
    "Couldn't send email address change confirmation mail. Please contact your administrator." : "Kon bevestigingsbericht voor wijziging e-mailadres niet versturen. Neem contact op met uw beheerder.",
    "%s email address changed successfully" : "%s e-mailadres succesvol gewijzigd.",
    "Couldn't send email address change notification mail. Please contact your administrator." : "Kon meldingssbericht voor wijziging e-mailadres niet versturen. Neem contact op met uw beheerder.",
    "Unable to enable/disable user." : "Kan gebruiker niet activeren/deactiveren.",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "__language_name__" : "Nederlands",
    "Language changed" : "Taal aangepast",
    "Invalid request" : "Ongeldige aanvraag",
    "Admins can't remove themself from the admin group" : "Admins kunnen zichzelf niet uit de admin groep verwijderen",
    "Unknown user" : "Onbekende gebruiker",
    "Couldn't remove app." : "Kon app niet verwijderen.",
    "Official" : "Officieel",
    "Approved" : "Goedgekeurd",
    "All" : "Alle",
    "Enabled" : "Geactiveerd",
    "Not enabled" : "Niet ingeschakeld",
    "No apps found for your version" : "Geen apps gevonden voor uw versie",
    "The app will be downloaded from the app store" : "De app zal worden gedownload van de app store",
    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Officiële apps zijn ontwikkeld door en binnen de ownCloud community. Ze bieden functionaliteit binnen ownCloud en zijn klaar voor gebruik in een productie omgeving.",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Goedgekeurde apps zijn ontwikkeld door vertrouwde ontwikkelaars en hebben een beveiligingscontrole ondergaan. Ze worden actief onderhouden in een open code repository en hun ontwikkelaars vinden ze stabiel genoeg voor informeel of normaal gebruik.",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Deze app is niet gecontroleerd op beveiligingsproblemen en is nieuw is is bekend als onstabiel. Installeren op eigen risico.",
    "Please wait...." : "Even geduld a.u.b.",
    "Error while disabling app" : "Fout tijdens het uitzetten van de app",
    "Disable" : "Uitschakelen",
    "Enable" : "Activeer",
    "Error while enabling app" : "Fout tijdens het aanzetten van het programma",
    "Error: this app cannot be enabled because it makes the server unstable" : "Fout: deze app kan niet geïnstalleerd worden, omdat het de server onstabiel maakt",
    "Error: could not disable broken app" : "Fout: kan kapotte app niet uitschakelen",
    "Error while disabling broken app" : "Fout bij het uitzetten van de niet werkende app",
    "Updating...." : "Bijwerken....",
    "Error while updating app" : "Fout bij bijwerken app",
    "Updated" : "Bijgewerkt",
    "Uninstalling ...." : "De-installeren ...",
    "Error while uninstalling app" : "Fout bij de-installeren app",
    "Uninstall" : "De-installeren",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "De app is geactiveerd maar moet worden bijgewerkt. U wordt over 5 seconden doorgeleid naar de bijwerkpagina.",
    "App update" : "App update",
    "Experimental" : "Experimenteel",
    "No apps found for {query}" : "Geen apps gevonden voor {query}",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Weet u zeker dat u \"{domain}\" als een vertrouwd domein wilt toevoegen?",
    "Add trusted domain" : "Vertrouwd domein toevoegen",
    "Migration in progress. Please wait until the migration is finished" : "Migratie bezig. Wacht tot het proces klaar is.",
    "Migration started …" : "Migratie gestart...",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Er trad een fout op. Upload als een ASCII-gecodeerd PEM certificaat.",
    "Valid until {date}" : "Geldig tot {date}",
    "Delete" : "Verwijder",
    "Disconnect" : "Verbreek verbinding",
    "Error while loading browser sessions and device tokens" : "Fout bij laden browser sessies en apparaat-tokens",
    "Error while creating device token" : "Fout bij creëren apparaat-token",
    "Error while deleting the token" : "Fout bij verwijderen token",
    "Sending..." : "Versturen...",
    "Failed to change the email address." : "Kan e-mailadres niet wijzigen",
    "Email changed successfully." : "E-mailadres succesvol gewijzigd.",
    "An error occurred: {message}" : "Er heeft zich een fout voorgedaan: {message}",
    "Select a profile picture" : "Kies een profielafbeelding",
    "Very weak password" : "Zeer zwak wachtwoord",
    "Weak password" : "Zwak wachtwoord",
    "So-so password" : "Matig wachtwoord",
    "Good password" : "Goed wachtwoord",
    "Strong password" : "Sterk wachtwoord",
    "Groups" : "Groepen",
    "Unable to delete {objName}" : "Kan {objName} niet verwijderen",
    "Error creating group: {message}" : "Fout bij aanmaken groep: {message}",
    "A valid group name must be provided" : "Er moet een geldige groepsnaam worden opgegeven",
    "deleted {groupName}" : "verwijderd {groupName}",
    "undo" : "ongedaan maken",
    "never" : "geen",
    "deleted {userName}" : "verwijderd {userName}",
    "add group" : "Nieuwe groep",
    "Invalid quota value \"{val}\"" : "Ongeldige quota waarde \"{val}\"",
    "enabled" : "ingeschakeld",
    "disabled" : "uitgeschakeld",
    "User {uid} has been {state}!" : "Gebruiker {uid} was {state}!",
    "no group" : "geen groep",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Wijzigen van het wachtwoord leidt tot gegevensverlies, omdat gegevensherstel voor deze gebruiker niet beschikbaar is",
    "Password successfully changed" : "Wachtwoord succesvol gewijzigd",
    "A valid username must be provided" : "Er moet een geldige gebruikersnaam worden opgegeven",
    "Error creating user: {message}" : "Fout bij aanmaken gebruiker: {message}",
    "A valid password must be provided" : "Er moet een geldig wachtwoord worden opgegeven",
    "A valid email must be provided" : "Er moet een geldig e-mailadres worden opgegeven",
    "Use the following link to confirm your changes to the email address: {link}" : "Gebruik de volgende link om de wijziging van uw e-mailadres te bevestigen: {link}",
    "Email address changed to {mailAddress} successfully." : "E-mailadres succesvol gewijzigd naar {mailAddress}.",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Hallo daar,<br><br>we willen u laten weten dat u nu een %s account hebt.<br><br>Uw gebruikersnaam: %s<br>Ga naar: <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "Proficiat!",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Hallo,\n\nwe willen u laten weten dat u nu een %s account hebt.\n\nUw gebruikersnaam: %s\nGa naar: %s\n\n",
    "User documentation" : "Gebruikersdocumentatie",
    "Administrator documentation" : "Beheerdersdocumentatie",
    "Online documentation" : "Online documentatie",
    "Forum" : "Forum",
    "Issue tracker" : "Issue tracker",
    "Commercial support" : "Commerciële ondersteuning",
    "Apps Management" : "Apps Management",
    "Developer documentation" : "Ontwikkelaarsdocumentatie",
    "by %s" : "op %s",
    "%s-licensed" : "%s-licensed",
    "Documentation:" : "Documentatie:",
    "Admin documentation" : "Beheerdocumentatie",
    "Visit website" : "Bezoek website",
    "Report a bug" : "Rapporteer een fout",
    "Show description …" : "Toon beschrijving ...",
    "Hide description …" : "Verberg beschrijving ...",
    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Deze app heeft geen minimum ownCloud versienummer toegewezen gekregen. Dit wordt een fout in ownCloud 11 en later.",
    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Deze app heeft geen maximum ownCloud versienummer toegewezen gekregen. Dit wordt een fout in ownCloud 11 en later.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Deze app kan niet worden geïnstalleerd, omdat de volgende afhankelijkheden niet zijn ingevuld:",
    "Enable only for specific groups" : "Alleen voor bepaalde groepen activeren",
    "Uninstall App" : "De-installeren app",
    "Show enabled apps" : "Toon ingeschakelde apps",
    "Show disabled apps" : "Toon uitgeschakelde apps",
    "Cron" : "Cron",
    "Last cron job execution: %s." : "Laatst uitgevoerde cronjob: %s.",
    "Last cron job execution: %s. Something seems wrong." : "Laatst uitgevoerde cronjob: %s. Er lijkt iets fout gegaan.",
    "Cron was not executed yet!" : "Cron is nog niet uitgevoerd!",
    "Open documentation" : "Open documentatie",
    "Execute one task with each page loaded" : "Bij laden van elke pagina één taak uitvoeren",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php is geregisteerd bij een webcron service om elke 15 minuten cron.php over http aan te roepen.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Gebruik de systeem cron service om cron.php elke 15 minuten aan te roepen.",
    "SSL Root Certificates" : "SSL Root Certificaten",
    "Common Name" : "Common Name",
    "Valid until" : "Geldig tot",
    "Issued By" : "Uitgegeven door",
    "Valid until %s" : "Geldig tot %s",
    "Import root certificate" : "Importeren root certificaat",
    "Server-side encryption" : "Server-side versleuteling",
    "Enable server-side encryption" : "Server-side versleuteling inschakelen",
    "Please read carefully before activating server-side encryption: " : "Lees dit goed, voordat u de serverside versleuteling activeert:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Als versleuteling is ingeschakeld, worden alle geüploade bestanden vanaf dat moment versleuteld opgeslagen op de server.  Het is alleen mogelijk om de versleuteling later uit te schakelen als de actieve versleutelingsmodule dit ondersteunt en aan alle pré-condities (mn de ingestelde herstelsleutel) wordt voldaan.",
    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "Alleen maar versleutelen is geen garantie voor veiligheid van het systeem. Lees de ownCloud documentatie voor meer informatie over de versleutelingsapp en de ondersteunde use cases.",
    "Be aware that encryption always increases the file size." : "Let erop dat versleuteling de bestandsomvang altijd laat toenemen.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Het is altijd verstandig om regelmatig backups van uw bestanden te maken. Zorg ervoor dat u in geval van versleuteling ook de cryptosleutel met uw gegevens backupt.",
    "This is the final warning: Do you really want to enable encryption?" : "Dit is de laatste waarschuwing: Wilt u versleuteling echt inschakelen?",
    "Enable encryption" : "Versleuteling inschakelen",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Er is geen cryptomodule geladen, activeer een cryptomodule in het appmenu",
    "Select default encryption module:" : "Selecteer de standaard cryptomodule:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "U moet uw cryptosleutels van de oude versleuteling (ownCloud <= 8.0) migreren naar de nieuwe. Activeer de \"Standaard cryptomodule\" en start 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "U moet uw cryptosleutels van de oude versleuteling (ownCloud <= 8.0) migreren naar de nieuwe.",
    "Start migration" : "Start migratie",
    "Sharing" : "Delen",
    "Allow apps to use the Share API" : "Apps toestaan de Share API te gebruiken",
    "Allow users to share via link" : "Sta gebruikers toe om te delen via een link",
    "Allow public uploads" : "Sta publieke uploads toe",
    "Enforce password protection" : "Dwing wachtwoordbeveiliging af",
    "Set default expiration date" : "Stel standaard vervaldatum in",
    "Allow users to send mail notification for shared files" : "Sta gebruikers toe om e-mailnotificaties  te versturen voor gedeelde bestanden",
    "Allow users to share file via social media" : "Toestaan dat gebruikers delen via sociale media",
    "Expire after " : "Vervalt na",
    "days" : "dagen",
    "Enforce expiration date" : "Verplicht de vervaldatum",
    "Allow resharing" : "Toestaan opnieuw delen",
    "Allow sharing with groups" : "Sta delen met groepen toe",
    "Restrict users to only share with users in their groups" : "Laat gebruikers alleen delen met andere gebruikers in hun groepen",
    "Allow users to send mail notification for shared files to other users" : "Sta gebruikers toe om e-mailnotificaties aan andere gebruikers te versturen voor gedeelde bestanden",
    "Exclude groups from sharing" : "Sluit groepen uit van delen",
    "These groups will still be able to receive shares, but not to initiate them." : "Deze groepen kunnen gedeelde mappen bestanden ontvangen, maar kunnen ze niet starten.",
    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Sta auto-aanvullen van gebruikersnaam toe in de Delen-dialoog. Als dit is uitgeschakeld, moet de gebruikersnaam volledig worden ingevuld.",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Alles (fatale problemen, fouten, waarschuwingen, info, debug)",
    "Info, warnings, errors and fatal issues" : "Info, waarschuwingen, fouten en fatale problemen",
    "Warnings, errors and fatal issues" : "Waarschuwingen, fouten en fatale problemen",
    "Errors and fatal issues" : "Fouten en fatale problemen",
    "Fatal issues only" : "Alleen fatale problemen",
    "Log" : "Log",
    "What to log" : "Wat loggen",
    "Download logfile (%s)" : "Download logbestand (%s)",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Het logbestand is groter dan 100MB. Downloaden kost even tijd!",
    "None" : "Geen",
    "Login" : "Login",
    "Plain" : "Gewoon",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "E-mailserver",
    "This is used for sending out notifications." : "Dit wordt gebruikt voor het verzenden van meldingen.",
    "Send mode" : "Verstuurmodus",
    "Encryption" : "Versleuteling",
    "From address" : "Afzenderadres",
    "mail" : "e-mail",
    "Authentication method" : "Authenticatiemethode",
    "Authentication required" : "Authenticatie vereist",
    "Server address" : "Server adres",
    "Port" : "Poort",
    "Credentials" : "Inloggegevens",
    "SMTP Username" : "SMTP gebruikersnaam",
    "SMTP Password" : "SMTP wachtwoord",
    "Store credentials" : "Opslaan inloggegevens",
    "Test email settings" : "Test e-mailinstellingen",
    "Send email" : "Versturen e-mail",
    "Security & setup warnings" : "Beveiligings- en instellingswaarschuwingen",
    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "php lijkt niet goed te zijn ingesteld om systeemomgevingsvariabelen te bevragen. De test met getenv(\"PATH\") gaf een leeg resultaat.",
    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Verifieer de <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installatiedocumentatie ↗</a> voor php configuratie notities en de php configuratie van uw server, zeker als php-fpm wordt gebruikt.",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "De Alleen-lezen config is geactiveerd. Dit voorkomt het via de webinterface wijzigen van verschillende instellingen. Bovendien moet het bestand voor elke aanpassing handmatig op beschrijfbaar worden ingesteld.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP is blijkbaar zo ingesteld dat inline doc blokken worden gestript. Hierdoor worden verschillende kernmodules onbruikbaar.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dit wordt vermoedelijk veroorzaakt door een cache/accelerator, zoals Zend OPcache of eAccelerator.",
    "Your database does not run with \"READ COMMITED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Uw database draait niet met \"READ COMMITED\" transactie isolatie niveau. Dit kan problemen opleveren als er meerdere acties tegelijkertijd worden uitgevoerd.",
    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "%1$s lager dan versie %2$s geïnstalleerd, voor betere stabiliteit en prestaties adviseren wij om %1$s te upgraden naar een nieuwere versie.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "De PHP module 'fileinfo' ontbreekt. We adviseren met klem om deze module te activeren om de beste resultaten te bereiken voor mime-type detectie.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Transactionele bestandlocking is gedeactiveerd, dat zou kunnen leiden tot versiebeheerproblemen. Schakel 'filelocking enabled' in config.php in om deze problemen te voorkomen. Zie de  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentatie ↗</a> voor meer informatie.",
    "Transactional file locking should be configured to use memory-based locking, not the default slow database-based locking. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Transactionele bestandlocking zou moeten worden geconfigureerd voor locking in het geheugen, niet op het trage databaseniveau. Zie de  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentatie ↗</a> voor meer informatie.",
    "System locale can not be set to a one which supports UTF-8." : "De systeemtaal kan niet worden ingesteld op een taal die UTF-8 ondersteunt.",
    "This means that there might be problems with certain characters in file names." : "Dat betekent dat er problemen kunnen optreden met bepaalde tekens in bestandsnamen.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "We adviseren met klem om de noodzakelijke pakketten op uw systeem te installeren om een van de volgende talen te ondersteunen: %s.",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Als uw installatie niet in de hoofddirectory van het domein staat, maar wel cron gebruikt, dan kunnen er problemen ontstaan bij het genereren van URL's. Om deze problemen te voorkomen zou u de \"overwrite.cli.url\" optie in config.php moeten instellen op het webroot pad van uw ownCloud (aanbevolen: \"%s\") ",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite wordt gebruikt als database. Voor grotere installaties adviseren we om te schakelen naar een andere database engine.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Vooral wanneer de desktop client wordt gebruik voor bestandssynchronisatie wordt gebruik van sqlite afgeraden.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "Om te migreren naar een andere database moet u de commandoregel tool gebruiken: 'occ db:convert-type', lees de  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentatie ↗</a>.",
    "We recommend to enable system cron as any other cron method has possible performance and reliability implications." : "We adviseren om de systeem cron in te schakelen, omdat andere cron methodes prestaties en betrouwbaarheid kunnen beïnvloeden.",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "het was niet mogelijk om de cronjob via CLI uit te voeren. De volgende technische problemen traden op:",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Lees de  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installatie handleiding</a> goed door en controleer op fouten en waarschuwingen in de <a href=\"#log-section\">logging</a>.",
    "All checks passed." : "Alle checks geslaagd",
    "System Status" : "Systemstatus",
    "Tips & tricks" : "Tips & trucs",
    "How to do backups" : "Hoe maak je back-ups",
    "Advanced monitoring" : "Geavanceerde monitoring",
    "Performance tuning" : "Prestatie afstelling",
    "Improving the config.php" : "config.php verbeteren",
    "Theming" : "Thema's",
    "Hardening and security guidance" : "Hardening en security advies",
    "Get the apps to sync your files" : "Download de apps om bestanden te synchroniseren",
    "Desktop client" : "Desktop client",
    "Android app" : "Android app",
    "iOS app" : "iOS app",
    "If you want to support the project\n\t\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\t\tor\n\t\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Als u het project wilt ondersteunen\n⇥⇥⇥<a href=\"https://owncloud.org/contribute\"\n⇥⇥⇥target=\"_blank\" rel=\"noreferrer\">ontwikkel mee</a>\n⇥⇥⇥of\n⇥⇥⇥<a href=\"https://owncloud.org/promote\"\n⇥⇥⇥target=\"_blank\" rel=\"noreferrer\">verkondig het nieuws</a>!",
    "Show First Run Wizard again" : "Toon de Eerste start Wizard opnieuw",
    "Profile picture" : "Profielafbeelding",
    "Upload new" : "Upload een nieuwe",
    "Select from Files" : "Kies uit bestanden",
    "Remove image" : "Afbeelding verwijderen",
    "png or jpg, max. 20 MB" : "png of jpg, max. 20 MB",
    "Picture provided by original account" : "Afbeelding is verstrekt door originele account.",
    "Cancel" : "Annuleer",
    "Choose as profile picture" : "Kies als profielafbeelding",
    "Full name" : "Volledige naam",
    "No display name set" : "Nog geen weergavenaam ingesteld",
    "Email" : "E-mailadres",
    "Your email address" : "Uw e-mailadres",
    "Change email" : "Wijzigen e-mailadres",
    "Set email" : "Instellen e-mailadres",
    "For password recovery and notifications" : "Voor wachtwoordherstel en meldingen",
    "No email address set" : "Geen e-mailadres opgegeven",
    "You are member of the following groups:" : "U bent lid van de volgende groepen:",
    "Password" : "Wachtwoord",
    "Unable to change your password" : "Niet in staat om uw wachtwoord te wijzigen",
    "Current password" : "Huidig wachtwoord",
    "New password" : "Nieuw",
    "Change password" : "Wijzig wachtwoord",
    "Language" : "Taal",
    "Help translate" : "Help met vertalen",
    "Unlimited" : "Ongelimiteerd",
    "You are using %s of %s" : "U gebruikt %s van %s",
    "You are using %s of %s (%s %%)" : "U gebruikt %s van %s (%s %%)",
    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Ontwikkeld door de {communityopen}ownCloud gemeenschap{linkclose}, de {githubopen}source code{linkclose} is gelicenseerd onder de {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
    "Sessions" : "Sessies",
    "These are the web, desktop and mobile clients currently logged in to your ownCloud." : "Dit zijn de web, desktop en mobiele clients die momenteel zijn verbonden met uw ownCloud.",
    "Browser" : "Browser",
    "Most recent activity" : "Meest recente activiteit",
    "App passwords" : "App wachtwoorden",
    "You've linked these apps." : "U hebt deze apps gelinkt.",
    "Name" : "Naam",
    "An app password is a passcode that gives an app or device permissions to access your %s account." : "Een app wachtwoord is een toegangscode waarmee een app of apparaat toegang krijgt om uw %s account te gebruiken.",
    "App name" : "App naam",
    "Create new app password" : "Creëer nieuw app wachtwoord",
    "Use the credentials below to configure your app or device." : "Gebruik onderstaande inloggegevens om uw app of apparaat te configureren.",
    "Username" : "Gebruikersnaam",
    "Done" : "Gedaan",
    "Version" : "Versie",
    "Personal" : "Persoonlijk",
    "Admin" : "Beheerder",
    "Error" : "Fout",
    "No panels for this section." : "Geen panels voor deze sectie.",
    "Show enabled/disabled option" : "Tonen ingeschakeld/uitgeschakeld optie",
    "Show storage location" : "Toon opslaglocatie",
    "Show last log in" : "Toon laatste inlog",
    "Show user backend" : "Toon backend gebruiker",
    "Send email to new user" : "Verstuur e-mail aan nieuwe gebruiker",
    "Show email address" : "Toon e-mailadres",
    "E-Mail" : "E-mail",
    "Create" : "Aanmaken",
    "Admin Recovery Password" : "Beheer herstel wachtwoord",
    "Enter the recovery password in order to recover the users files during password change" : "Voer het herstel wachtwoord in om de gebruikersbestanden terug te halen bij wachtwoordwijziging",
    "Add Group" : "Toevoegen groep",
    "Group" : "Groep",
    "Everyone" : "Iedereen",
    "Admins" : "Beheerders",
    "Default Quota" : "Standaard limiet",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Geef de opslagquotering op (bijv. \"512 MB\" of \"12 GB\")",
    "Other" : "Anders",
    "Full Name" : "Volledige naam",
    "Group Admin for" : "Groepsbeheerder voor",
    "Quota" : "Limieten",
    "Storage Location" : "Opslaglocatie",
    "User Backend" : "Backend gebruiker",
    "Last Login" : "Laatste inlog",
    "change full name" : "wijzigen volledige naam",
    "set new password" : "Instellen nieuw wachtwoord",
    "change email address" : "wijzig e-mailadres",
    "Default" : "Standaard",
    "Change" : "Wijzigen",
    "Share" : "Deel",
    "installing and updating apps via the market or Federated Cloud Sharing" : "installeren en bijwerken applicaties via de app store of Federated Cloud Sharing",
    "Domain" : "Domein",
    "Add Domain" : "Toevoegen domein",
    "CORS" : "CORS",
    "User ID" : "User ID",
    "Email address" : "E-mailadres",
    "Restrict enumeration to group members" : "Beperk enumeratie tot groepsleden",
    "No Domains." : "Geen domainen.",
    "Add" : "Toevoegen",
    "The config file is read only. Please adjust your setup by editing the config file manually." : "Het configuratiebestand is alleen-lezen. Wijzig uw setup door door het configuratiebestand handmatig te wijzigen."
},
"nplurals=2; plural=(n != 1);");
